@@ -4,7 +4,7 @@ CSSFileInput <- function(id, label) {
     tags$label(label),
     div(
       class = "custom-file",
-      tags$input(id = id, type = "file", class = "custom-file-input", accept = ".css"),
+      tags$input(id = id, type = "file", accept = ".css"),
       tags$label(class = "custom-file-label", `for` = id, "Choose file")
     )
   )
