@@ -9,7 +9,7 @@ SettingsModUI <- function(id) {
   ns <- NS(id)
 
   div(
-    class = "row settings-row row-cols-3",
+    class = "row settings-row row-cols-4",
     settingsDropdownButton(
       id = ns("page_type_button"),
       label = "Page Type",
@@ -25,6 +25,16 @@ SettingsModUI <- function(id) {
         CodeModUI(ns("code"))
       )
     ),
+    settingsDropdownButton(
+      id = ns("template_button"),
+      label = "Templates",
+      contents = div(
+        id = ns("template_dropdown"),
+        `aria-labelledby` = ns("template_button"),
+        class = "dropdown-menu dropdown-menu-wide clickable-dropdown",
+        TemplateModUI(ns("template"))
+      )
+    ),
     settingsDropdownButton(
       id = ns("options_button"),
       label = "Settings",
